@@ -3,10 +3,9 @@ from django.conf import settings
 from django.urls import reverse
 
 from djangoldp.utils import is_authenticated_user
-from djangoldp_stripe.permissions import user_has_subscriptions_in_products_list
+from djangoldp_stripe.permissions import user_has_any_active_subscription
 
 
-required_product_subs = set(getattr(settings, 'PERMS_REQUIRED_STRIPE_SUBSCRIPTIONS_GLOBALLY', []))
 include_paths = getattr(settings, 'INCLUDE_FROM_GLOBAL_STRIPE_SUBSCRIPTION_REQ', [])
 
 
@@ -18,10 +17,9 @@ class StripeSubscriptionRequiredMiddleware:
         return request.path in include_paths
 
     def __call__(self, request):
-        if is_authenticated_user(request.user) and self._request_path_included(request) \
-            and len(required_product_subs) > 0:
+        if is_authenticated_user(request.user) and self._request_path_included(request):
 
-            if not user_has_subscriptions_in_products_list(request.user, required_product_subs):
+            if not user_has_any_active_subscription(request.user):
                 raise PermissionDenied('user must be subscribed to required products to access this site')
         
         return self.get_response(request)
